<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="17"/>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD yksikkötestaus</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="32"/>
      <source>Test</source>
      <translation>Testi</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="44"/>
      <source>Select test name:</source>
      <translation>Valitse testin nimi:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="96"/>
      <source>&amp;Start</source>
      <translation>&amp;Aloita</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="99"/>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="128"/>
      <source>&amp;Help</source>
      <translation>Ohje</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="131"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="141"/>
      <source>&amp;About</source>
      <translation>&amp;Tietoja</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="144"/>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="154"/>
      <source>&amp;Close</source>
      <translation>&amp;Sulje</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="157"/>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="169"/>
      <source>Progress</source>
      <translation>Tilanne</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="188"/>
      <source>Run:</source>
      <translation>Suorita:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="205"/>
      <source>Failures:</source>
      <translation>Hylätyt:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="222"/>
      <source>Errors:</source>
      <translation>Virheet:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="239"/>
      <source>Remaining:</source>
      <translation>Jäljellä oleva:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="259"/>
      <source>Failures and errors</source>
      <translation>Hylätyt toiminnot ja virheet</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="275"/>
      <source>Description</source>
      <translation>Kuvaus</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="292"/>
      <source>Idle</source>
      <translation>Joutokäynti</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="166"/>
      <source>Help</source>
      <translation>Helppi</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="166"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Anna kutsuttavan objektin nimi, jota käytettäessä palautetaan testCase.
Napsauta 'alkaa', ja näin tuotettu testi suoritetaan.

Kaksoisnapsauta puunäkymässä olevaa virhettä nähdäksesi lisää tietoa siitä, mukaan lukien pinottu jälki.</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="178"/>
      <source>About FreeCAD UnitTest</source>
      <translation>Tietoja FreeCAD-yksikkötestauksesta</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="178"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest on osa FreeCADia ja se tukee UnitTestien kirjoittamista käyttäjän omille moduuleille.</translation>
    </message>
  </context>
</TS>
